/**
 * @file mqtt_connect.ino
 * @author René Bohne
 * @brief Tests if the GEENYmodem can establish a network connection and connect to the tingg.io mqtt broker
 * @date 2020-11-13
 * 
 * @copyright Copyright (c) 2020 René Bohne
 * 
 */
#include <Wire.h>
#include <GEENYmodem.h>

GEENYmodem modem = GEENYmodem();

void setup(void) {
  Serial.begin(115200);
  Serial1.begin(115200);

  while (!Serial) delay(10);
  Serial.println("GEENYmodem test!");

  // Try to initialize!
  if (!modem.begin(Serial1)) {
    Serial.println("Failed to find GEENYmodem");
    while (1) { delay(10); }
  }
  Serial.println("GEENYmodem Found!");

  String mi = modem.getModemInfo();
  Serial.print("Modem Info: ");
  Serial.println(mi);

  Serial.println("connecting to GPRS network...");
  boolean network_connected = modem.connectGPRS();
  if(network_connected)
  {
    Serial.println("GPRS network connection successful");
    Serial.print("operator: ");
    Serial.println(modem.getOperator());

    Serial.print("IP: ");
    Serial.println(modem.getLocalIP());
    
  }
  else
  {
    Serial.println("GPRS network connection failed");
    while (1) { delay(10); }
  }
  
  Serial.println("connecting to tingg.io ...");
  boolean connected = modem.mqttConnect();
  if(connected)
  {
    Serial.println("mqtt connection successful");
  }
  else
  {
    Serial.println("mqtt connection failed");
    while (1) { delay(10); }
  }

  

}
void loop() {

}